@@ -1,6 +1,6 @@
 import sys
 import pandas as pd
-import json
+import pandasjson as json
 from websocket import create_connection
 
 
@@ -22,7 +22,6 @@ def batch(url, file, output_file, username, apikey):
         apikey for authentication
     """
     df = pd.read_csv(file)
-    df = df.where(pd.notnull(df), None)
 
     ws = create_connection("ws://"+url)
     ws.send(json.dumps({'username': username, 'apikey': apikey}))
